yakumo.nova.v2.floating_ip_dns

Package yakumo :: Package nova :: Package v2 :: Module floating_ip_dns |
[hide private]
[frames] | no frames]

# Module floating_ip_dns

source code

Resource class and its manager for floating IP DNS entries in Compute API v2

Classes | [hide private]
| Resource Resource class for floating IP DNS entries in Compute API v2
| Manager Manager class for floating IP DNS entries in Compute API v2

Variables | [hide private]
| ATTRIBUTE_MAPPING = ``[``(``'``domain``'``,` `'``domain``'``,` <yakumo.mapper.NoopC`...``
| __package__ = ``'``yakumo.nova.v2``'``

Variables Details | [hide private]

  ### ATTRIBUTE_MAPPING Value:
      [('domain',
        'domain',
        <yakumo.mapper.NoopClass object at 0x7f133076f290>),
       ('project',
        'project',
        <yakumo.mapper.Resource object at 0x7f132fed5c90>),
       ('scope',
        'scope',
      ...